==> okta-sdk-api-20.0.1-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ResourceSets.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksNext;
import com.okta.sdk.resource.model.ResourceSet;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSets
 */
@JsonPropertyOrder({ ResourceSets.JSON_PROPERTY_RESOURCE_SETS, ResourceSets.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-01-23T09:50:29.349096-06:00[America/Chicago]", comments = "Generator version: 7.8.0")
public class ResourceSets implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESOURCE_SETS = "resource-sets";
    private List<ResourceSet> resourceSets = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private LinksNext links;

    public ResourceSets() {
    }

    public ResourceSets resourceSets(List<ResourceSet> resourceSets) {

        this.resourceSets = resourceSets;
        return this;
    }

    public ResourceSets addresourceSetsItem(ResourceSet resourceSetsItem) {
        if (this.resourceSets == null) {
            this.resourceSets = new ArrayList<>();
        }
        this.resourceSets.add(resourceSetsItem);
        return this;
    }

    /**
     * Get resourceSets
     *
     * @return resourceSets
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_RESOURCE_SETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<ResourceSet> getResourceSets() {
        return resourceSets;
    }

    @JsonProperty(JSON_PROPERTY_RESOURCE_SETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setResourceSets(List<ResourceSet> resourceSets) {
        this.resourceSets = resourceSets;
    }

    public ResourceSets links(LinksNext links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksNext getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(LinksNext links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSets resourceSets = (ResourceSets) o;
        return Objects.equals(this.resourceSets, resourceSets.resourceSets)
                && Objects.equals(this.links, resourceSets.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resourceSets, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSets {\n");
        sb.append("    resourceSets: ").append(toIndentedString(resourceSets)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/ResourceSets.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.LinksNext;
import com.okta.sdk.resource.model.ResourceSet;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * ResourceSets
 */
@JsonPropertyOrder({ ResourceSets.JSON_PROPERTY_RESOURCE_SETS, ResourceSets.JSON_PROPERTY_LINKS })
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class ResourceSets implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_RESOURCE_SETS = "resource-sets";
    private List<ResourceSet> resourceSets = null;

    public static final String JSON_PROPERTY_LINKS = "_links";
    private LinksNext links;

    public ResourceSets() {
    }

    public ResourceSets resourceSets(List<ResourceSet> resourceSets) {

        this.resourceSets = resourceSets;
        return this;
    }

    public ResourceSets addresourceSetsItem(ResourceSet resourceSetsItem) {
        if (this.resourceSets == null) {
            this.resourceSets = new ArrayList<>();
        }
        this.resourceSets.add(resourceSetsItem);
        return this;
    }

    /**
     * Get resourceSets
     *
     * @return resourceSets
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_RESOURCE_SETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public List<ResourceSet> getResourceSets() {
        return resourceSets;
    }

    @JsonProperty(JSON_PROPERTY_RESOURCE_SETS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setResourceSets(List<ResourceSet> resourceSets) {
        this.resourceSets = resourceSets;
    }

    public ResourceSets links(LinksNext links) {

        this.links = links;
        return this;
    }

    /**
     * Get links
     *
     * @return links
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public LinksNext getLinks() {
        return links;
    }

    @JsonProperty(JSON_PROPERTY_LINKS)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setLinks(LinksNext links) {
        this.links = links;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        ResourceSets resourceSets = (ResourceSets) o;
        return Objects.equals(this.resourceSets, resourceSets.resourceSets)
                && Objects.equals(this.links, resourceSets.links);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(resourceSets, links);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class ResourceSets {\n");
        sb.append("    resourceSets: ").append(toIndentedString(resourceSets)).append("\n");
        sb.append("    links: ").append(toIndentedString(links)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
